@@ -65,4 +65,7 @@ modules:
 - keep_alive
 - xdg_open
 - bash
+- required_restart
+- disk_usage
+- nvidia_gpu
 """
